import Joi, { ObjectSchema } from 'joi';
import { Algorithm, SignOptions } from 'jsonwebtoken';
export * from 'jsonwebtoken';
export declare enum TokenKind {
    TOKEN = "TOKEN",
    REFRESH_TOKEN = "REFRESH_TOKEN"
}
export declare enum AppDomain {
    MERCHANT = "MERCHANT",
    CONSUMER = "CONSUMER",
    ADMIN = "ADMIN"
}
export declare type BaseToken = {
    kind: TokenKind;
    uuid: string;
    appDomain: AppDomain;
    productEntityUuid?: string;
};
export declare const schemaBaseToken: {
    kind: Joi.StringSchema;
    uuid: Joi.StringSchema;
    appDomain: Joi.StringSchema;
    productEntityUuid: Joi.StringSchema;
};
export declare type BaseTokenClaim = BaseToken & {
    iat?: number;
    exp?: number;
};
export declare const schemaBaseTokenClaim: {
    iat: Joi.NumberSchema;
    exp: Joi.NumberSchema;
    kind: Joi.StringSchema;
    uuid: Joi.StringSchema;
    appDomain: Joi.StringSchema;
    productEntityUuid: Joi.StringSchema;
};
export declare abstract class JwtBaseToken<T> {
    protected readonly secret: string;
    protected readonly schema: ObjectSchema<T>;
    protected readonly signOptions: SignOptions;
    constructor(secret: string, expiresIn: string | number, schema: ObjectSchema<T>, algorithm?: Algorithm);
    sign(payload: T, expiresIn?: string | number, notBefore?: string | number): string;
    verify(token: string): T;
}
