"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.JwtIdToken = exports.schemaIdTokenClaim = void 0;
const joi_1 = __importDefault(require("joi"));
const cm_libs_context_aware_error_1 = require("cm-libs-context-aware-error");
const auth_base_token_1 = require("./auth-base-token");
const _uuid = joi_1.default.string().length(21);
const _localeCode = joi_1.default.string().max(10);
exports.schemaIdTokenClaim = {
    ...auth_base_token_1.schemaBaseTokenClaim,
    userUuid: _uuid.required(),
    localeCode: _localeCode.required()
};
class JwtIdToken extends auth_base_token_1.JwtBaseToken {
    constructor(secret, expiresIn, schema, algorithm) {
        super(secret, expiresIn, schema, algorithm);
    }
    static init(secret, expiresIn, algorithm) {
        this.self = new JwtIdToken(secret, expiresIn, joi_1.default.object(exports.schemaIdTokenClaim), algorithm);
        return this;
    }
    static term() {
        this.self = undefined;
    }
    static sign(claim, expiresIn, notBefore) {
        if (auth_base_token_1.TokenKind.TOKEN !== claim.kind) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.MISMATCHED, 'Token kind is invalid', { claim });
        }
        return JwtIdToken.instance.sign(claim, expiresIn, notBefore);
    }
    static verify(token) {
        const claim = JwtIdToken.instance.verify(token);
        /* istanbul ignore next */
        if (auth_base_token_1.TokenKind.TOKEN !== claim.kind) {
            (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.MISMATCHED, 'Token kind is invalid', { claim });
        }
        return claim;
    }
    static get instance() {
        return this.self || (0, cm_libs_context_aware_error_1.throwError)(cm_libs_context_aware_error_1.errors.NOT_INITIALIZED, 'JwtIdToken initialization is required');
    }
    static get isEnabled() {
        return undefined !== this.self;
    }
}
exports.JwtIdToken = JwtIdToken;
//# sourceMappingURL=auth-id-token.js.map